@@ -6,12 +6,12 @@
 """
 from typing import Union, Tuple
 from enstools.encoding.definitions import Compressors
-from enstools.encoding.encodings import FilterEncodingForH5py, FilterEncodingForXarray
+from enstools.encoding.api import FilterEncodingForH5py, FilterEncodingForXarray, check_libpressio_availability,\
+    check_zfp_availability, check_sz_availability, check_blosc_availability
+from enstools.core.errors import EnstoolsError
 import xarray
 import numpy
 
-from enstools.core.errors import EnstoolsError
-
 
 def emulate_compression_on_dataset(dataset: xarray.Dataset, compression: Union[str, dict], in_place: bool = True):
     """
@@ -62,28 +62,41 @@ def emulate_compression_on_data_array(data_array: xarray.DataArray, compression_
 
 def emulate_compression_on_numpy_array(data: numpy.ndarray, compression_specification: FilterEncodingForH5py) -> \
         Tuple[numpy.ndarray, dict]:
-    # TODO: Ugly dependency, maybe think about a better place to put that.
-
     if compression_specification.compressor in [Compressors.BLOSC, Compressors.NONE]:
         return data, {}
-    from enstools.compression.analyzer.LibpressioAnalysisCompressor import compressor_configuration
-    try:
-        from libpressio import PressioCompressor
-    except ModuleNotFoundError as err:
-        raise EnstoolsError(
-            "The library libpressio its not available, can not proceed with emulation.")
+
+    # For performance reasons, Libpressio is the preferred backend for emulation.
+    # It will be used if available, otherwise we will rely on the filters and
+    if check_libpressio_availability():
+        from enstools.compression.emulators import LibpressioEmulator
+        emulator_backend = LibpressioEmulator
+    else:
+        from enstools.compression.emulators.FiltersEmulator import FilterEmulator
+        emulator_backend = FilterEmulator
+        # Check that the proper filter is actually available:
+        if not check_compressor_availability(compression_specification.compressor):
+            raise EnstoolsError(f"Trying to use {compression_specification.compressor!r} which is not available")
+
     uncompressed_data = data
     decompressed_data = uncompressed_data.copy()
 
-    compressor_name = compression_specification.compressor
-    mode = compression_specification.mode
-    parameter = compression_specification.parameter
-    # compressor_name, mode, parameter = parse_compression(compression_specification)
-    config = compressor_configuration(compressor_name, mode, parameter, data)
-    compressor = PressioCompressor.from_config(config)
+    compressor = emulator_backend(
+        compressor_name=compression_specification.compressor,
+        mode= compression_specification.mode,
+        parameter=compression_specification.parameter,
+        uncompressed_data=decompressed_data)
 
-    # preform compression and decompression
-    compressed = compressor.encode(uncompressed_data)
-    decompressed = compressor.decode(compressed, decompressed_data)
-    metrics = compressor.get_metrics()
+    decompressed = compressor.compress_and_decompress(decompressed_data)
+    metrics = {"compression_ratio": compressor.compression_ratio()}
     return decompressed, metrics
+
+
+def check_compressor_availability(compressor: Compressors) -> bool:
+    if compressor is Compressors.ZFP:
+        return check_zfp_availability()
+    elif compressor is Compressors.SZ:
+        return check_sz_availability()
+    elif compressor is Compressors.BLOSC:
+        return check_blosc_availability()
+    else:
+        raise NotImplementedError(f"Compressor: {compressor} hasn't been implemented.")
